TelecomMASAgent class

Main class for the Telecom Multi-Agent System

Constructors

TelecomMASAgent({String agentName = 'Telecom MAS Agent'})

Properties

agentName String
final
hashCode int
The hash code for this object.
no setterinherited
pushNotifications List<PushNotification>
Get all push notifications
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sentMessages List<SentMessage>
Get all sent messages
no setter
userIds List<String>
Get all user IDs
no setter

Methods

checkCallBalance(String userId) Future<String>
Check call balance for a user
getBalance(String userId) int
Get the current balance for a user
getMarketingInsights(String userId) Future<MarketingInsights>
Get marketing insights for a user
getUserLogs(String userId) List<UserLog>
Get all logs for a specific user
hasUser(String userId) bool
Check if a user exists
initializeUser(String userId, {int initialBalance = 100}) Future<String>
Initialize a user with a balance
makeCall(String userId, int minutes) Future<String>
Simulate making a call that deducts minutes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendPushNotification(String userId, String message) Future<String>
Send a push notification
sendSMS(String userId, String message) Future<String>
Send an SMS message
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited